aboutsummaryrefslogtreecommitdiffstats
path: root/awkgram.c
diff options
context:
space:
mode:
authorArnold D. Robbins <arnold@skeeve.com>2015-06-25 23:12:55 +0300
committerArnold D. Robbins <arnold@skeeve.com>2015-06-25 23:12:55 +0300
commit056cd074c60d940d5bb46410f114a6c2584daaae (patch)
treee2b095b3740b35cc95a8b25fd10ee5d81288565e /awkgram.c
parent5b246a31d63a31180136934adbed361651f325ba (diff)
parent3712ad29b6cddcf49bf1507f5677a49ccfcff83d (diff)
downloadegawk-056cd074c60d940d5bb46410f114a6c2584daaae.tar.gz
egawk-056cd074c60d940d5bb46410f114a6c2584daaae.tar.bz2
egawk-056cd074c60d940d5bb46410f114a6c2584daaae.zip
Merge branch 'master' into feature/cmake
Diffstat (limited to 'awkgram.c')
-rw-r--r--awkgram.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/awkgram.c b/awkgram.c
index 12f648ed..a1a055b6 100644
--- a/awkgram.c
+++ b/awkgram.c
@@ -6700,7 +6700,7 @@ snode(INSTRUCTION *subn, INSTRUCTION *r)
} else if (r->builtin == do_isarray || r->builtin == do_typeof) {
arg = subn->nexti;
if (arg->nexti == arg->lasti && arg->nexti->opcode == Op_push)
- arg->nexti->opcode = Op_push_arg; /* argument may be array */
+ arg->nexti->opcode = Op_push_arg_untyped; /* argument may be untyped */
} else if (r->builtin == do_intdiv
#ifdef HAVE_MPFR
|| r->builtin == MPF(intdiv)
@@ -6895,6 +6895,8 @@ valinfo(NODE *n, Func_print print_func, FILE *fp)
{
if (n == Nnull_string)
print_func(fp, "uninitialized scalar\n");
+ else if (n->type == Node_typedregex)
+ print_func(fp, "@/%.*s/\n", n->re_exp->stlen, n->re_exp->stptr);
else if ((n->flags & STRING) != 0) {
pp_string_fp(print_func, fp, n->stptr, n->stlen, '"', false);
print_func(fp, "\n");